# encoding: utf-8

# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-bcc_auto.ycp
# Package:	Configuration of novell-bcc
# Summary:	Client for autoinstallation
# Authors:	Ryan Okelberry <rokelberry@novell.com>
#
# $Id: novell-bcc_auto.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of novell-bcc settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("novell-bcc_auto", [ "Summary", mm ]);
module Yast
  class NovellBccAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-bcc"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellBcc auto started")

      Yast.import "NovellBcc"
      Yast.include self, "novell-bcc/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(NovellBcc.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        NovellBcc.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        @ret = NovellBccAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = NovellBcc.Import(@param)
      # Return actual state
      elsif @func == "Export"
        @ret = NovellBcc.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = NovellBcc.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = NovellBcc.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        NovellBcc.write_only = true
        @ret = NovellBcc.Write
        Progress.set(@progress_orig)
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellBcc auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellBccAutoClient.new.main
