# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-bcc_proposal.ycp
# Package:	Configuration of novell-bcc
# Summary:	Proposal function dispatcher.
# Authors:	Ryan Okelberry <rokelberry@novell.com>
#
# $Id: novell-bcc_proposal.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# Proposal function dispatcher for novell-bcc configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NovellBccProposalClient < Client
    def main

      textdomain "novell-bcc"

      Yast.import "NovellBcc"
      Yast.import "Progress"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellBcc proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = nil
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !NovellBcc.proposal_valid
          NovellBcc.proposal_valid = true
          @progress_orig = Progress.set(false)
          NovellBcc.Read
          Progress.set(@progress_orig)
        end
        @sum = NovellBcc.Summary
        @proposal = Ops.get_string(@sum, 0, "")

        @ret = {
          "preformatted_proposal" => @proposal,
          "warning_level"         => @warning_level,
          "warning"               => @warning
        }
      # run the module
      elsif @func == "AskUser"
        @stored = NovellBcc.Export
        @seq = Convert.to_symbol(
          WFM.CallFunction("novell-bcc", [path(".propose")])
        )
        NovellBcc.Import(@stored) if @seq != :next
        Builtins.y2debug("stored=%1", @stored)
        Builtins.y2debug("seq=%1", @seq)
        @ret = { "workflow_sequence" => @seq }
      # create titles
      elsif @func == "Description"
        @ret = {
          # Rich text title for NovellBcc in proposals
          "rich_text_title" => _(
            "OES Bcc"
          ),
          # Menu title for NovellBcc in proposals
          "menu_title"      => _(
            "&OES Bcc"
          ),
          "id"              => "novell-bcc"
        }
      # write the proposal
      elsif @func == "Write"
        NovellBcc.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellBcc proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellBccProposalClient.new.main
