# encoding: utf-8

# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-bcc/complex.ycp
# Package:	Configuration of novell-bcc
# Summary:	Dialogs definitions
# Authors:	Ryan Okelberry <rokelberry@novell.com>
#
# $Id: complex.ycp 29363 2006-03-24 08:20:43Z mzugec $
module Yast
  module NovellBccComplexInclude
    def initialize_novell_bcc_complex(include_target)
      Yast.import "UI"

      textdomain "novell-bcc"

      Yast.import "Label"
      Yast.import "Popup"
      Yast.import "Wizard"
      Yast.import "UIHelper"
      Yast.import "Confirm"
      Yast.import "NovellBcc"


      Yast.include include_target, "novell-bcc/helps.rb"
      Yast.include include_target, "novell-bcc/upgrade.rb"
    end

    # Return a modification status
    # @return true if data was modified
    def Modified
      NovellBcc.Modified
    end

    def ReallyAbort
      !NovellBcc.Modified || Popup.ReallyAbort(true)
    end

    def PollAbort
      UI.PollInput == :abort
    end

    # Read settings dialog
    # @return `abort if aborted and `next otherwise
    def ReadDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "read", ""))
      # NovellBcc::AbortFunction = PollAbort;
      return :abort if !Confirm.MustBeRoot
      ret = NovellBcc.Read
      ret ? :next : :abort
    end

    # Write settings dialog
    # @return `abort if aborted and `next otherwise
    def WriteDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "write", ""))
      # NovellBcc::AbortFunction = PollAbort;
      ret = NovellBcc.Write
      ret ? :next : :abort
    end

    # Overview dialog
    # @return dialog result
    def OverviewDialog
      # Bcc overview dialog caption
      caption = _("Bcc Overview")

      overview = NovellBcc.Overview

      # FIXME table header
      contents = UIHelper.EditTable(
        # Table header
        Header(_("Number"), _("Bcc")),
        overview,
        nil,
        nil,
        nil,
        nil
      )

      contents = UIHelper.SpacingAround(contents, 1.5, 1.5, 1.0, 1.0)


      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "overview", ""),
        Label.BackButton,
        Label.FinishButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # add
        elsif ret == :add_button
          # FIXME
          ret = :add
          break
        # edit
        elsif ret == :edit_button
          # FIXME
          ret = :edit
          break
        # delete
        elsif ret == :delete_button
          # FIXME
          next
        elsif ret == :next || ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end
  end
end
