# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-bcc/dialogs.ycp
# Package:	Configuration of novell-bcc
# Summary:	Dialogs definitions
# Authors:	Ryan Okelberry <rokelberry@novell.com>
#
# $Id: dialogs.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellBccDialogsInclude
    def initialize_novell_bcc_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-bcc"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "NovellBcc"
      Yast.import "Service"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "Ncs"
      Yast.import "Popup"

      Yast.include include_target, "novell-bcc/helps.rb"
      Yast.include include_target, "novell-bcc/complex.rb"
    end

    # Configure1 dialog
    # @return dialog result
    def ConfigurationDialog
      # dialog caption
      caption = _("OES Business Continuity Cluster (BCC) Configuration")

      #	boolean newInstall = NovellBcc::Settings["CONFIG_BCC_CONFIG_TYPE"]:"New" == "New";
      newInstall = true
      startBcc = Ops.get_string(
        NovellBcc.Settings,
        "CONFIG_BCC_START_NOW",
        "yes"
      ) == "yes"
      clusterDN = Ops.get_string(
        NovellBcc.Settings,
        "CONFIG_BCC_CLUSTER_DN",
        ""
      )

      # Ncs NewOrExisting dialog contents
      ldap_servers = Ops.get_list(
        NovellBcc.Settings,
        "CONFIG_LDAP_SERVER_LIST",
        []
      )
      Builtins.y2debug("Pre-filter list of ldap servers: %1", ldap_servers)
      ldap_servers = Builtins.filter(ldap_servers) do |address|
        NovellLDAP.AddressExists(address, nil)
      end
      Builtins.y2debug("Post-filter list of ldap servers: %1", ldap_servers)

      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      Builtins.y2debug("Server list: %1", server_list)

      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("Directory Server Addresses"),
        Ops.get(ldap_servers, 0, ""),
        true,
        :multi
      )

      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      contents = HVSquash(
        VBox(
          TextEntry(
            Id(:clusterDN),
            Opt(:notify),
            _("Existing Cluster DN (e.g. cn=cluster.o=microfocus)"),
            clusterDN
          ),
          # 			`Frame( _("Select Configuration Type"),
          # 				`RadioButtonGroup(`id(`config),
          # 					`VBox(
          # 						`Left(`RadioButton(
          # 							`id(`new),
          # 							`opt(`notify),
          # 							_("New Configuration"),
          # 							newInstall)),
          #
          # 						`Left(`RadioButton(
          # 							`id(`upgrade),
          # 							`opt(`notify),
          # 							_("Upgrade an Existing Configuration"),
          # 							!newInstall))
          # 					)
          # 				)
          # 			),
          ldap_widget,
          Left(
            CheckBox(
              Id(:start),
              Opt(:notify),
              _("Start Business Continuity Cluster Services Now"),
              startBcc
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "configure", ""),
        nil,
        Label.NextButton
      )

      Wizard.DisableBackButton

      while true
        NovellLDAPUI.AdminPasswordDialog
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          doPass = Popup.AnyQuestion(
            _("Password not entered"),
            _(
              "An LDAP password is required to continue. Do you wish to try again or abort?"
            ),
            _("&Enter Password"),
            _("&Abort"),
            :focus_yes
          )
          if doPass # They want to try entering the password again.
            next # Abort the install
          else
            return :abort
          end
        else
          break
        end
      end

      ret = nil

      while true
        ret = UI.UserInput

        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next || ret == :back
          ldap_servers = Convert.convert(
            UI.QueryWidget(Id(:server_select), :SelectedItems),
            :from => "any",
            :to   => "list <string>"
          )
          if nil == ldap_servers || [] == ldap_servers
            Popup.Error(_("At least one directory server must be selected."))
            UI.SetFocus(Id(:server_select))
            next
          end
          Ops.set(NovellBcc.Settings, "CONFIG_LDAP_SERVER_LIST", ldap_servers)
          break
        # 		else if (ret == `new) {
        # 			NovellBcc::Settings["CONFIG_BCC_CONFIG_TYPE"] = "New";
        # 		}
        # 		else if (ret == `upgrade) {
        # 			NovellBcc::Settings["CONFIG_BCC_CONFIG_TYPE"] = "Upgrade";
        # 		}
        elsif ret == :clusterDN
          Ops.set(
            NovellBcc.Settings,
            "CONFIG_BCC_CLUSTER_DN",
            Convert.to_string(UI.QueryWidget(Id(:clusterDN), :Value))
          )
        elsif ret == :start
          Ops.set(
            NovellBcc.Settings,
            "CONFIG_BCC_START_NOW",
            Convert.to_boolean(UI.QueryWidget(Id(:start), :Value)) ? "yes" : "no"
          )
        else
          next
        end
      end

      deep_copy(ret)
    end

    # Summary dialog
    # @return dialog result
    def SummaryDialog
      caption = _(
        "OES Business Continuity Cluster (BCC) Configuration Summary"
      )

      upgrade = Ops.get_string(
        NovellBcc.Settings,
        "CONFIG_BCC_CONFIG_TYPE",
        "New"
      ) == "Upgrade"
      startNow = Ops.get_string(
        NovellBcc.Settings,
        "CONFIG_BCC_START_NOW",
        "yes"
      ) == "yes"
      error = false

      contents = RichText("")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      message = ""
      message = Ops.add(message, _("<p><b> LDAP Configuration </b><ul>"))
      message = Ops.add(message, _("<li><b> Server Address(es):</b><ul>"))
      Builtins.foreach(
        Ops.get_list(NovellBcc.Settings, "CONFIG_LDAP_SERVER_LIST", [])
      ) do |ldap_server|
        message = Ops.add(
          Ops.add(Ops.add(message, "<li>"), ldap_server),
          "</li>"
        )
      end 

      message = Ops.add(message, _("</ul></li>"))

      message = Ops.add(
        Ops.add(
          Ops.add(message, _("<li><b> Admin Name:</b> ")),
          Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
        ),
        "</li>"
      )
      message = Ops.add(
        Ops.add(
          Ops.add(message, _("<li><b> Existing Cluster DN: </b>")),
          Ops.get_string(NovellBcc.Settings, "CONFIG_BCC_CLUSTER_DN", "")
        ),
        "</li>"
      )
      message = Ops.add(message, _("</ul></p>"))

      if upgrade
        message = Ops.add(
          message,
          _("<p><b> Upgrade BCC Enabled Cluster Volume Resources </b>")
        )
        upgradeInfo = []

        if !(
            upgradeInfo_ref = arg_ref(upgradeInfo);
            _GetUpgradeInfo_result = GetUpgradeInfo(upgradeInfo_ref);
            upgradeInfo = upgradeInfo_ref.value;
            _GetUpgradeInfo_result
          )
          message = Ops.add(
            message,
            _(
              "<ul><li><font color=\"red\"> Error getting existing cluster configuration.  Please verify configuration settings. </li></ul>"
            )
          )
          error = true
        else
          if 0 == Builtins.size(upgradeInfo)
            message = Ops.add(
              message,
              _("<ul><li> No Volume Resources Found </li></ul>")
            )
          else
            message = Ops.add(message, "<ul>")
            Builtins.foreach(upgradeInfo) do |entry|
              message = Ops.add(
                Ops.add(message, _("<li><b> Resource Name: </b>")),
                Ops.get_string(entry, "cn", "")
              )
              message = Ops.add(
                Ops.add(
                  Ops.add(message, _("<br/><b> Associated Pool: </b>")),
                  Ops.get_string(entry, "poolDN", "")
                ),
                "</li>"
              )
            end 

            message = Ops.add(message, "</ul></p>")
          end
        end
      end

      if startNow
        message = Ops.add(message, _("<p><b> Start BCC Services Now </b></p>"))
      end

      contents = RichText(message)
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "summary", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.ChangeWidget(Id(:next), :Enabled, false) if error

      ret = nil
      while true
        ret = UI.UserInput

        if ret == :abort
          if Popup.ReallyAbort(false)
            break
          else
            next
          end
        elsif ret == :next || ret == :back
          break
        else
          next
        end
      end
      deep_copy(ret)
    end

    def CongratulationsDialog
      caption = _("Congratulations...")
      message = _("<p><b>OES Business Continuity Cluster (BCC) is now configured for use.</b></p><ul>")

      if !Service.Enabled("novell-bcc")
        message = Ops.add(
          message,
          _("<li>To have BCC services start automatically upon boot, execute <code>systemctl enable novell-bcc.service</code> from a shell</li>.")
        )
      end

      if Service.Status("novell-bcc") != 0
        message = Ops.add(
          message,
          _("<li>To start BCC services now, execute <code>systemctl status novell-bcc.service</code> from a shell.</li>")
        )
      end

      message = Ops.add(
        message,
        _("<li>To enable BCC with OES Cluster Services (NCS), visit the <b>Clusters</b> role in <b>iManager</b>.</li>")
      )

      message = Ops.add(
        message,
        _("<li>Please visit <b><a>https://www.microfocus.com/documentation/business-continuity-clustering/</a></b> and refer the the Known Issues page.</li></ul>")
      )

      contents = RichText(message)

      Wizard.SetContentsButtons(caption, contents, "", "", Label.FinishButton)

      UI.ChangeWidget(Id(:abort), :Enabled, false)

      UI.UserInput
    end
  end
end
