# encoding: utf-8

# File:	include/bcc/upgrade.ycp
# Package:	Configuration of bcc
# Summary:	Code to handler upgrading BCC from 1.0 to 1.1
# Authors:	Ryan Okelberry <rokelberry@novell.com>
#
# $Id: upgrade.ycp 172 2005-09-30 19:10:40Z rokelberry $
module Yast
  module NovellBccUpgradeInclude
    def initialize_novell_bcc_upgrade(include_target)
      textdomain "novell-bcc"
      Yast.import "Report"
      Yast.import "Wizard"
      Yast.import "Label"
      Yast.import "Popup"
      Yast.import "NovellBcc"
      Yast.import "NovellUtils"
      Yast.import "IP"
    end

    def LdapInit
      ret = Convert.to_boolean(
        SCR.Execute(
          path(".ldap"),
          {
            "hostname" => Ops.get_string(
              NovellBcc.Settings,
              "CONFIG_BCC_LDAP_IP",
              ""
            ),
            "port"     => Ops.get_integer(
              NovellBcc.Settings,
              "CONFIG_BCC_LDAP_PORT",
              389
            ),
            "use_tls"  => "yes"
          }
        )
      )

      if !ret
        Report.Error(_("Problem initializing LDAP connection."))
        return false
      end

      ret = Convert.to_boolean(
        SCR.Execute(
          path(".ldap.bind"),
          {
            "bind_dn" => NovellUtils.Nds2Ldap(
              Ops.get_string(NovellBcc.Settings, "CONFIG_BCC_ADMIN_DN", "")
            ),
            "bind_pw" => Ops.get_string(
              NovellBcc.Settings,
              "CONFIG_BCC_ADMIN_PASSWORD",
              ""
            )
          }
        )
      )

      if !ret
        Report.Error(_("Problem binding to LDAP server."))
        return false
      end

      nil
    end

    def GetPoolDN(volumeDNs, poolDN)
      volumeDNs = deep_copy(volumeDNs)
      attrs = []
      poolDN.value = ""

      Builtins.foreach(volumeDNs) do |volumeDN|
        info = Convert.convert(
          SCR.Read(
            path(".ldap.search"),
            { "base_dn" => volumeDN, "attrs" => ["nssfsPool"], "scope" => 2 }
          ),
          :from => "any",
          :to   => "list <map>"
        )
        if nil == info
          Report.Error(_("Error querying LDAP."))
          next false
        end
        if 1 == Builtins.size(info) && "" == poolDN.value
          attrs = Ops.get_list(Ops.get(info, 0, {}), "nssfspool", [])
          poolDN.value = Ops.get(attrs, 0, "")
        end
      end 

      true
    end

    def GetLUNMap(poolDN, lunMap)
      attrs = []
      lunMap.value = ""

      info = Convert.convert(
        SCR.Read(
          path(".ldap.search"),
          { "base_dn" => poolDN, "attrs" => ["ncsbcclunmap"], "scope" => 2 }
        ),
        :from => "any",
        :to   => "list <map>"
      )

      if nil == info
        Report.Error(_("Error querying LDAP."))
        return false
      end

      if 1 == Builtins.size(info) && "" == lunMap.value
        attrs = Ops.get_list(Ops.get(info, 0, {}), "ncsbcclunmap", [])
        lunMap.value = Ops.get(attrs, 0, "")
      end
      true
    end

    def GetNodeInfo(nodeList)
      nodeList.value = []

      clusterDN = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellBcc.Settings, "CONFIG_BCC_CLUSTER_DN", "")
      )

      return false if !LdapInit()

      nodeInfo = Convert.convert(
        SCR.Read(
          path(".ldap.search"),
          {
            "base_dn" => clusterDN,
            #				"filter": "(&(objectClass=nCSNCPServer)(nCSNodeIsolationScript=*))",
            "filter"  => "(&(objectClass=nCSNCPServer))",
            "scope"   => 2
          }
        ),
        :from => "any",
        :to   => "list <map>"
      )

      return false if nil == nodeInfo

      Builtins.foreach(nodeInfo) do |node|
        info = {}
        sa = Ops.get_list(node, "ncsnetworkaddress", [])
        address = Builtins.substring(Ops.get(sa, 0, ""), 2)
        res = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Ops.add(
              Ops.add("echo -n ", address),
              " | hexdump -e '1/1 \"%01x\"'"
            )
          )
        )
        Ops.set(info, "name", Ops.get(Ops.get_list(node, "cn", []), 0, ""))
        Ops.set(
          info,
          "address",
          IP.ToString(
            Builtins.tointeger(Ops.add("0x", Ops.get_string(res, "stdout", "")))
          )
        )
        Ops.set(
          info,
          "linux",
          Ops.get_string(node, "ncsnodeisolationscript", "") != ""
        )
        Ops.set(nodeList.value, Builtins.size(nodeList.value), info)
      end 

      true
    end

    def GetUpgradeInfo(info)
      info.value = []

      clusterDN = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellBcc.Settings, "CONFIG_BCC_CLUSTER_DN", "")
      )

      if "" == clusterDN
        Report.Error(_("No cluster DN was specified."))
        return false
      end

      return false if !LdapInit()

      resources = Convert.convert(
        SCR.Read(
          path(".ldap.search"),
          {
            "base_dn" => clusterDN,
            "filter"  => "(&(objectClass=nCSBCCResource)(objectClass=nCSVolumeResource)(nCSVolumes=*))",
            "attrs"   => ["cn", "dn", "objectClass", "nCSVolumes"],
            "scope"   => 2
          }
        ),
        :from => "any",
        :to   => "list <map>"
      )

      if nil == resources
        Report.Error(_("Error searching LDAP for existing volume resources."))
        return false
      end

      Builtins.foreach(resources) do |resource|
        attr = Ops.get_list(resource, "cn", [])
        cn = Ops.get(attr, 0, "")
        dn = Ops.add(Ops.add(Ops.add("cn=", cn), ","), clusterDN)
        volumes = Ops.get_list(resource, "ncsvolumes", [])
        poolDN = ""
        if !(
            poolDN_ref = arg_ref(poolDN);
            _GetPoolDN_result = GetPoolDN(volumes, poolDN_ref);
            poolDN = poolDN_ref.value;
            _GetPoolDN_result
          )
          next false
        end
        lunMap = ""
        if !(
            lunMap_ref = arg_ref(lunMap);
            _GetLUNMap_result = GetLUNMap(poolDN, lunMap_ref);
            lunMap = lunMap_ref.value;
            _GetLUNMap_result
          )
          next false
        end
        Ops.set(
          info.value,
          Builtins.size(info.value),
          {
            "cn"        => cn,
            "dn"        => dn,
            "volumeDNs" => volumes,
            "poolDN"    => poolDN,
            "lunMap"    => lunMap
          }
        )
      end 

      true
    end

    # PerformUpgrade
    #	Perform 1.0 -> 1.1 upgrade (modify eDir)
    #
    # @param [list <map> &] info IN list of maps containing upgrade info
    # @param [list <map> &] failed OUT list of maps containing upgrade info which failed
    # @return [Boolean] true iff no errors
    def PerformUpgrade(info, failed)
      # TODO
      true
    end
  end
end
